import { Box, Image, Progress, Text, VStack } from '@chakra-ui/react';
import React from 'react';
import { getFeatures } from '@brojs/cli';
import { useTranslation } from 'react-i18next';

import { formatPrice, getProgressColor } from './helper';

const PRICE_INCREASE_PERCENT_PER_RATING = 10;

export const PriceCar = ({ image, rating, description }) => {
  const BASE_WASH_PRICE: number = Number(
    getFeatures('dry-wash')['order-cost']?.value || 1000,
  );

  const calculateWashPrice = (rating: number) => {
    const priceIncrease =
      (BASE_WASH_PRICE * PRICE_INCREASE_PERCENT_PER_RATING * rating) / 100;
    return BASE_WASH_PRICE + priceIncrease;
  };

  const { i18n, t } = useTranslation('~', {
    keyPrefix: 'dry-wash.order-view.price-car',
  });
  const washPrice = calculateWashPrice(rating);
  const formattedPrice = formatPrice(washPrice, i18n.language);

  const progressValue = (rating / 10) * 100;

  return (
    <Box
      gap={5}
      width='100%'
      display='flex'
      justifyContent='center'
      alignItems='flex-start'
      flexWrap='wrap'
    >
      <Image
        maxWidth='600px'
        width='100%'
        objectFit='contain'
        borderRadius='md'
        src={image}
        alt=''
      />
      <Box flex='1 1 40%'>
        {!Number.isNaN(progressValue) ? (
          <VStack alignItems='stretch'>
            <Box>
              <Text>{t('title')}</Text>
              <Progress
                value={progressValue}
                size='sm'
                sx={{
                  '& > div': {
                    backgroundColor: getProgressColor(progressValue),
                  },
                }}
                mt={2}
              />
              <Text mt={2}>
                {t('description')} <b>{formattedPrice}</b>
              </Text>
            </Box>
            <Text fontStyle='italic'>{description}</Text>
          </VStack>
        ) : (
          <Text>{t('error')}</Text>
        )}
      </Box>
    </Box>
  );
};

export default PriceCar;
