import React, { FC } from 'react';
import {
  Alert,
  AlertIcon,
  Heading,
  HStack,
  UnorderedList,
  ListItem,
  Text,
  Flex,
} from '@chakra-ui/react';
import { useTranslation } from 'react-i18next';
import dayjs from 'dayjs';
import localizedFormat from 'dayjs/plugin/localizedFormat';
dayjs.extend(localizedFormat);
import 'dayjs/locale/ru';
import 'dayjs/locale/en';

import { Order } from '../../../models/landing';
import { formatDatetime } from '../../../lib';
import { carBodySelectOptions, carColorSelectOptions } from '../../order-form';

import { OrderStatus } from './status';
import { CarDetails } from './car';

type OrderDetailsProps = Pick<
  Order.View,
  | 'orderNumber'
  | 'status'
  | 'phone'
  | 'carNumber'
  | 'carBody'
  | 'carColor'
  | 'location'
  | 'startWashTime'
  | 'endWashTime'
  | 'created'
>;

export const OrderDetails: FC<OrderDetailsProps> = ({
  orderNumber,
  status,
  phone,
  carNumber,
  carBody,
  carColor,
  location,
  startWashTime,
  endWashTime,
  created,
}) => {
  const { t, i18n } = useTranslation('~', {
    keyPrefix: 'dry-wash.order-view.details',
  });
  dayjs.locale(i18n.language);
  const { t: tCarBody } = useTranslation('~', {
    keyPrefix: 'dry-wash.order-create.car-body-select.options',
  });
  const { t: tCarColor } = useTranslation('~', {
    keyPrefix: 'dry-wash.order-create.car-color-select.colors',
  });
  const carColorTKey = carColorSelectOptions.find(
    ({ value }) => value === carColor,
  )?.labelTKey;

  return (
    <>
      <Heading as='h2' size='lg' marginInline='auto'>
        {t('title', { number: orderNumber })}
      </Heading>
      <HStack
        width='full'
        flexWrap='wrap'
        justifyContent='space-between'
        gap={2}
      >
        <Text>{dayjs(created).format('LLL')}</Text>
        <OrderStatus value={status} />
      </HStack>
      <Flex direction={{ base: 'column', md: 'row-reverse' }} gap={4}>
        <CarDetails
          carNumber={carNumber}
          carBody={carBody}
          carColor={carColor}
        />
        <UnorderedList styleType='none'>
          {[
            {
              label: t('car'),
              value: `${tCarBody(carBodySelectOptions.find(({ value }) => value === carBody)?.labelTKey)} (${carColorTKey ? tCarColor(carColorTKey) : carColor})`,
            },
            {
              label: t('owner'),
              value: phone,
            },
            {
              label: t('location'),
              value: location,
            },
            {
              label: t('datetime-range'),
              value: [
                formatDatetime(startWashTime),
                formatDatetime(endWashTime),
              ].join(' - '),
            },
          ].map(({ label, value }, i) => (
            <ListItem key={i}>
              <Text as='span' color='primary.400'>
                {label}:
              </Text>{' '}
              <Text as='span'>{value}</Text>
            </ListItem>
          ))}
        </UnorderedList>
      </Flex>
      <Alert status='info' alignItems='flex-start'>
        <AlertIcon />
        {t('alert')}
      </Alert>
    </>
  );
};

// todo: add i18n for date & time
